@@ -19,6 +19,11 @@ sub start_test_workers : Test(startup => 1) {
 sub test_01_load_balancing_async : Test(6) {
     my $self = shift;
 
+    if ($ENV{'AUTOMATED_TESTING'}) {
+        # Broker may fail to load balance evenly when running low of CPU resources
+        return "Load balancing tests are not deterministic";
+    }
+
     my $cli = Beekeeper::Client->instance;
     my $resp;
 
@@ -61,6 +66,11 @@ sub test_01_load_balancing_async : Test(6) {
 sub test_02_load_balancing_background : Test(6) {
     my $self = shift;
 
+    if ($ENV{'AUTOMATED_TESTING'}) {
+        # Broker may fail to load balance evenly when running low of CPU resources
+        return "Load balancing tests are not deterministic";
+    }
+
     my $cli = Beekeeper::Client->instance;
     my $resp;
 
@@ -102,6 +112,11 @@ sub test_02_load_balancing_background : Test(6) {
 sub test_03_slow_consumer_async : Test(6) {
     my $self = shift;
 
+    if ($ENV{'AUTOMATED_TESTING'}) {
+        # Broker may fail to load balance evenly when running low of CPU resources
+        return "Load balancing tests are not deterministic";
+    }
+
     my $cli = Beekeeper::Client->instance;
     my $resp;
 
